#!/bin/sh

if [ $# -ne 1 ]; then
echo "WARNING: Input parameter not specified!"
echo "Example:  ./remote_Lucent_UMTS_Snapshoot_ext.sh <parameter>"
exit 1
fi

AWK="/usr/bin/awk"
SED="/usr/bin/sed"
UNZIP="/usr/bin/unzip"

# Configurable variables. Set them for your environment
VENDOR_TECH="LUCENT-UMTS"
FTYPE="SnapShoot"
BASE_DIR=/home/mzadmin/spool/Lucent_UMTS/CM_Snapshoot
# Input parameter $1 = working directory
OSS_DIR=$BASE_DIR/$1
INPUT_DIR=$OSS_DIR/in
OUTPUT_DIR=$OSS_DIR/out
TEMP_DIR=$BASE_DIR/tmp
LOG_DIR=$BASE_DIR/logs

PROCESS_FILE=TRUE

if [ ! -d "$INPUT_DIR" -o ! -d "$OUTPUT_DIR" -o ! -d "$TEMP_DIR" -o ! -d "$LOG_DIR" ] ; then
   echo "Directories missing. Please check if input, output, temp and log directories are created."
   exit 1
fi

# Error messages
MSG_TIMEOUT_EXPIRED="TIMEOUT waiting files for extraction has expired."
MSG_MISSING_FILES="There are no files to be processed."
MSG_INVALID_FILE_NAME="The input filename is invalid. Extraction file cannot be generated for this file."
MSG_PRG_EXECUTION_FAILED="The execution of this program has failed."

# Function to create the error log file
create_log() {

   TS=`date +%Y%m%d%H%M`
   ID=$1
   ERROR_TYPE=$2

   case $ERROR_TYPE in
        TIMEOUT_EXPIRED) MSG=$MSG_TIMEOUT_EXPIRED ;;
        MISSING_FILES) MSG=$MSG_MISSING_FILES ;;
        INVALID_FILE_NAME) MSG=$MSG_INVALID_FILE_NAME ;;
        PRG_EXECUTION_FAILED) MSG=$MSG_PRG_EXECUTION_FAILED ;;
   esac

   flogname="$VENDOR_TECH.$FTYPE.$ERROR_TYPE.$ID.$TS.err"
   echo "[`date`] ID: $ID -  $MSG" > $TEMP_DIR/$flogname;
}

# Function to extract the required content
extract_content() {

tmpfile=$TEMP_DIR/tmpfile.$$
orig_file=$1;
xml_file=$2;

grep "\<associatedFDDCell\>" $xml_file | $SED 's/<[/]*associatedFDDCell>//g' > $tmpfile
mv $tmpfile $orig_file
mv $orig_file $OUTPUT_DIR

rm -f $xml_file

}

# Check if there are files to process
ls $INPUT_DIR/*WMScm > /dev/null 2>&1
RESULT=$?

if [ $RESULT -ne 0 ]; then

create_log "EMP" "MISSING_FILES"
PROCESS_FILE=FALSE
fi

# Process each zip file
if [ "$PROCESS_FILE" = "TRUE" ]; then
	for file in $INPUT_DIR/*.WMScm
	do
	
	xml_filename=`$UNZIP $file | grep inflating | $AWK '{print $2}'`
	extract_content $file $xml_filename
	RESULT=$?
	
	        if [ $RESULT -ne 0 ] ; then
	              # Create error log file
	              create_log "EXT" "PRG_EXECUTION_FAILED"
	              break
		fi
	
	done
fi

cd $TEMP_DIR
# Move the ERROR files to the logs directory
for f in `find . -name "*err"`
do
   mv $f $LOG_DIR
done


# END
